summaryrefslogtreecommitdiff
path: root/inc/request.h
diff options
context:
space:
mode:
authorBryan Ischo <bryan@ischo.com>2008-07-13 12:48:54 +0000
committerBryan Ischo <bryan@ischo.com>2008-07-13 12:48:54 +0000
commit77c7ea225a5c977e2590eb1b4e7451d26919b577 (patch)
treed25ddb1a53b3ac3d4b6053213fa2ac57530aa706 /inc/request.h
parent56a9e0707d0014327f57a71a0dbb2ec53e79a4c9 (diff)
downloadceph-libs3-77c7ea225a5c977e2590eb1b4e7451d26919b577.tar.gz
* More work in progress; fixed some bugs, initial get object implementation
Diffstat (limited to 'inc/request.h')
-rw-r--r--inc/request.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/inc/request.h b/inc/request.h
index a5ed101..d1df84a 100644
--- a/inc/request.h
+++ b/inc/request.h
@@ -73,11 +73,11 @@ typedef struct RequestParams
// AWS Secret Access Key
const char *secretAccessKey;
- // Request headers
- const S3RequestHeaders *requestHeaders;
+ // Put properties
+ const S3PutProperties *putProperties;
// Callback to be made when headers are available. Might not be called.
- S3ResponseHeadersCallback *headersCallback;
+ S3ResponsePropertiesCallback *propertiesCallback;
// Callback to be made to supply data to send to S3. Might not be called.
S3PutObjectDataCallback *toS3Callback;
@@ -119,7 +119,7 @@ typedef struct Request
int httpResponseCode;
// Callback to be made when headers are available. Might not be called.
- S3ResponseHeadersCallback *headersCallback;
+ S3ResponsePropertiesCallback *propertiesCallback;
// Callback to be made to supply data to send to S3. Might not be called.
S3PutObjectDataCallback *toS3Callback;
@@ -141,8 +141,8 @@ typedef struct Request
// Handler of response headers
ResponseHeadersHandler responseHeadersHandler;
- // This is set to nonzero after the haders callback has been made
- int headersCallbackMade;
+ // This is set to nonzero after the properties callback has been made
+ int propertiesCallbackMade;
// Parser of errors
ErrorParser errorParser;